@@ -265,7 +265,20 @@ def exportGraphml(o, nodes, edges, options, title="", reverse_epochs=False, ff=0
                         # Skip nodes that don't follow the expected format
                         pass
 
-    for i in sorted(epoch, reverse=tf):
+    # Determine epoch order
+    # When clusters are available, they're already in chronological order (oldest to newest)
+    # Use chronological order (not alphabetical) and reverse if needed
+    if clusters:
+        # Clusters are sorted by cluster_id (chronological order)
+        # If reverse_epochs, invert to show newest to oldest
+        epoch_ordered = list(reversed(epoch)) if tf else epoch
+        epoch_sigla_ordered = list(reversed(epoch_sigla)) if tf else epoch_sigla
+    else:
+        # Fallback: alphabetical sort (old behavior)
+        epoch_ordered = sorted(epoch, reverse=tf)
+        epoch_sigla_ordered = sorted(epoch_sigla, reverse=tf)
+
+    for i in epoch_ordered:
         color = "#"+''.join([random.choice('0123456789ABCDEF') for j in range(6)])
         s=i.split(' : ')
         a=len(i)
@@ -500,9 +513,9 @@ def exportGraphml(o, nodes, edges, options, title="", reverse_epochs=False, ff=0
     #n.initFromString(l)
     rows=doc.createElement('y:Rows')
     x=1000.0
-    
-    
-    for i in sorted(epoch,reverse=tf):
+
+
+    for i in epoch_ordered:
         
         
         s=i.split(' : ')
@@ -535,7 +548,7 @@ def exportGraphml(o, nodes, edges, options, title="", reverse_epochs=False, ff=0
     for k,nod in nodes.items():
 
 
-        nod.exportGraphml(doc, graph1, options, sorted(epoch_sigla, reverse=tf), node_to_cluster)
+        nod.exportGraphml(doc, graph1, options, epoch_sigla_ordered, node_to_cluster)
 
     node1.appendChild(graph1)
    
